==> ejc-scientific-impl-3.0.0-20250307.091015-45-sources.jar: com/ejianc/business/scientific/result/bean/MethodApplyEntity.java <==
package com.ejianc.business.scientific.result.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工法管理-工法申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_method_apply")
public class MethodApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // projectName
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // orgName
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织(二级单位Id)
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码(二级单位code)
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织(二级单位name)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="method_name")
    private String methodName; // 工法名称
    @TableField(value="method_type")
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    @TableField(value="method_person_id")
    private Long methodPersonId; //  工法完成人id
    @TableField(value="method_person_name")
    private String methodPersonName; //  工法完成人name
    @TableField(value="scientific_project_id")
    private Long scientificProjectId; // 所属科研项目id
    @TableField(value="scientific_project_name")
    private String scientificProjectName; // 所属科研项目name
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="use_status") //引用状态 0-未引用1-已引用
    private Integer useStatus;


    public Integer getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Integer useStatus) {
        this.useStatus = useStatus;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }
    public Long getMethodPersonId() {
        return methodPersonId;
    }

    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    public Long getScientificProjectId() {
        return scientificProjectId;
    }

    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250418.081255-74-sources.jar: com/ejianc/business/scientific/result/bean/MethodApplyEntity.java <==
package com.ejianc.business.scientific.result.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工法管理-工法申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_method_apply")
public class MethodApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // projectName
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // orgName
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织(二级单位Id)
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码(二级单位code)
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织(二级单位name)
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="method_name")
    private String methodName; // 工法名称
    @TableField(value="method_type")
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    @TableField(value="method_person_id")
    private Long methodPersonId; //  工法完成人id
    @TableField(value="method_person_name")
    private String methodPersonName; //  工法完成人name
    @TableField(value="scientific_project_id")
    private Long scientificProjectId; // 所属科研项目id
    @TableField(value="scientific_project_name")
    private String scientificProjectName; // 所属科研项目name
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="use_status") //引用状态 0-未引用1-已引用
    private Integer useStatus;
    @TableField(value="professional_classification")
    private String professionalClassification; // 专业分类
    @TableField(value="main_tec")
    private String mainTec; // 工法关键技术获得专利或科技成果奖励的情况
    @TableField(value="tech_standard_status")
    private String techStandardStatus; //工法形成企业技术标准情况
    @TableField(value="upgraded_construction_methods")
    private String upgradedConstructionMethods; //（升级版工法填写此栏）原工法名称、完成单   位、省级工法批准文号及工法编号
    @TableField(value="method_summary")
    private String methodSummary; //工法内容简述
    @TableField(exist = false)

    @SubEntity(serviceName = "methodApplyStatusService",pidName = "applyId")
    private List<MethodApplyStatusEntity> methodApplyStatusList=new ArrayList<>();
    @TableField(exist = false)
    @SubEntity(serviceName = "methodApplyPersonService",pidName = "applyId")
    private List<MethodApplyPersonEntity> methodApplyPersonEntityList=new ArrayList<>();



    public Integer getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Integer useStatus) {
        this.useStatus = useStatus;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }
    public Long getMethodPersonId() {
        return methodPersonId;
    }

    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    public Long getScientificProjectId() {
        return scientificProjectId;
    }

    public void setScientificProjectId(Long scientificProjectId) {
        this.scientificProjectId = scientificProjectId;
    }
    public String getScientificProjectName() {
        return scientificProjectName;
    }

    public void setScientificProjectName(String scientificProjectName) {
        this.scientificProjectName = scientificProjectName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProfessionalClassification() {
        return professionalClassification;
    }

    public void setProfessionalClassification(String professionalClassification) {
        this.professionalClassification = professionalClassification;
    }

    public String getMainTec() {
        return mainTec;
    }

    public void setMainTec(String mainTec) {
        this.mainTec = mainTec;
    }

    public String getTechStandardStatus() {
        return techStandardStatus;
    }

    public void setTechStandardStatus(String techStandardStatus) {
        this.techStandardStatus = techStandardStatus;
    }

    public String getUpgradedConstructionMethods() {
        return upgradedConstructionMethods;
    }

    public void setUpgradedConstructionMethods(String upgradedConstructionMethods) {
        this.upgradedConstructionMethods = upgradedConstructionMethods;
    }

    public String getMethodSummary() {
        return methodSummary;
    }

    public void setMethodSummary(String methodSummary) {
        this.methodSummary = methodSummary;
    }

    public List<MethodApplyStatusEntity> getMethodApplyStatusList() {
        return methodApplyStatusList;
    }

    public void setMethodApplyStatusList(List<MethodApplyStatusEntity> methodApplyStatusList) {
        this.methodApplyStatusList = methodApplyStatusList;
    }

    public List<MethodApplyPersonEntity> getMethodApplyPersonEntityList() {
        return methodApplyPersonEntityList;
    }

    public void setMethodApplyPersonEntityList(List<MethodApplyPersonEntity> methodApplyPersonEntityList) {
        this.methodApplyPersonEntityList = methodApplyPersonEntityList;
    }
}
